==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/models/mail_template.rb <==
# -*- coding: utf-8 -*-
require 'erb'
class MailTemplate < ActiveRecord::Base
  acts_as_paranoid
  attr_accessor :validate_for_pc_only
  attr_accessor :disp_count

  selectable_attr :mail_type_div do
    entry '1', :thanks, '注文受付メール', :pc_only => false
    entry '15', :thanks_bank_transfer, '注文受付（銀行振り込み）メール', :pc_only => true
    entry '2', :regist_user, 'ユーザ登録メール', :pc_only => false
    entry '3', :update_user, 'ユーザ退会メール', :pc_only => false
    entry '4', :cancel, 'キャンセル依頼メール', :pc_only => false
    entry '5', :cancel_complete, 'キャンセル完了メール', :pc_only => false
    entry '6', :inquiry, '問い合わせ受付メール', :pc_only => false
    entry '7', :reply, '問い合わせ回答メール', :pc_only => false
    entry '8', :order_reply, '注文問い合わせ回答メール', :pc_only => false
    entry '9', :shipment_instruction, '出荷指示メール', :pc_only => false, :ja_only => true
    entry '17', :shipment_complete_for_shop, '出荷完了メール（店舗宛て）', :pc_only => true, :ja_only => true
    entry '10', :shipment_complete, '出荷完了メール（顧客宛て）', :pc_only => false
    entry '14', :cancel_payment, '決済取り消し依頼メール', :pc_only => true, :ja_only => true
    entry '16', :receipt_payment, '入金確認メール', :pc_only => true
    entry '11', :project_check_request, 'プロジェクト確認依頼メール', :pc_only => true
    entry '12', :project_approval_request, 'プロジェクト承認依頼メール', :pc_only => true
    entry '13', :project_passback, 'プロジェクト差し戻しメール', :pc_only => true
    entry '98', :payment_error, '決済エラー連絡メール', :pc_only => true
    entry '99', :free, 'その他のメール', :pc_only => false
  end

  selectable_attr :content_type_div do
    entry '1', :text, 'テキストのみ'
    entry '2', :text_html, 'テキストとHTML形式'
  end

  selectable_attr :use_div do
    entry '0', :false, ' '
    entry '1', :true, '使用中'
  end

  # 必須チェック
  validates_presence_of :name, :mail_type_div, :pc_subject_template, :pc_text
  validates_presence_of :pc_html, :if => Proc.new{|t|t.content_type_div == MailTemplate.content_type_div_id_by_key(:text_html)}
  validates_presence_of :mobile_subject_template, :if => :for_mobile?
  validates_presence_of :mobile_text, :if => :for_mobile?
  validates_presence_of :mobile_html, :if => Proc.new{|t|t.content_type_div == MailTemplate.content_type_div_id_by_key(:text_html) && t.for_mobile?}

  # ユニークチェック
  validates_uniqueness_of :name

  # 長さチェック
  validates_length_of :name, :maximum => 255
  validates_length_of :pc_subject_template, :maximum => 255
  validates_length_of :pc_text, :maximum => 20000
  validates_length_of :mobile_subject_template, :maximum => 255, :if => :for_mobile?
  validates_format_of :content_type_div, :with => /^[1|2]$/

  # モバイルのチェックもする場合はtrueを返す
  def for_mobile?
    return !(self.validate_for_pc_only || self.mail_type_div_entry[:pc_only])
  end

  def validate
    if self.errors.size < 1
      validates_erb(ERB.new(self.pc_subject_template), 'pc_subject')
      validates_erb(ERB.new(self.pc_text), 'pc_text')
      validates_erb(ERB.new(self.pc_html), 'pc_html') if self.content_type_div_key == :text_html
      if for_mobile?
        validates_erb(ERB.new(self.mobile_subject_template), 'mobile_subject')
        validates_erb(ERB.new(self.mobile_text), 'mobile_text')
        validates_erb(ERB.new(self.mobile_html), 'mobile_html') if self.content_type_div_key == :text_html
      end
    end
  end

  # テンプレートの変更を反映して、使用区分を変更する
  def save_and_change_use_div
    MailTemplate.transaction do
      self.save!
      if self.use_div_key == :true
        mail_templates = MailTemplate.find(:all, :conditions => ['id != ? AND mail_type_div = ? AND use_div = ? AND locale = ?', self.id, self.mail_type_div, self.use_div, self.locale])
        mail_templates.each do |template|
          template.use_div = MailTemplate.use_div_id_by_key(:false)
          template.save!
        end
      end
    end
  end

  # メール件名をプレビューする
  def preview_mail_subject(pc_mobile_key)
    if pc_mobile_key == :mobile
      subject = ERB.new(self.mobile_subject_template) if self.mobile_subject_template
    else
      subject = ERB.new(self.pc_subject_template) if self.pc_subject_template
    end
    return ' ' if subject.blank?
    subject.result(template_test_obj(:text))
  end

  # メール本文をプレビューする
  def preview_mail_body(pc_mobile_key, text_html_key)
    if pc_mobile_key == :mobile && text_html_key == :html
      body = ERB.new(self.mobile_html)
    elsif pc_mobile_key == :mobile && text_html_key == :text
      body = ERB.new(self.mobile_text)
    elsif pc_mobile_key == :pc && text_html_key == :html
      body = ERB.new(self.pc_html)
    else
      body = ERB.new(self.pc_text)
    end

    return ' ' if body.blank?
    body.result(template_test_obj(text_html_key))
  end

  # 引数に渡されたメール区分の使用中テンプレートを取得する
  def self.find_valid_template(mail_type_key, locale = I18n.locale.to_s)
    mail_type_div = MailTemplate.mail_type_div_id_by_key(mail_type_key)

    #下記の順番でテンプレートを検索する
    # 1. 指定した言語
    result = find(:first, :conditions => {:mail_type_div => mail_type_div, :use_div => MailTemplate.use_div_id_by_key(:true), :locale => locale})
    # 2. 英語
    result ||= find(:first, :conditions => {:mail_type_div => mail_type_div, :use_div => MailTemplate.use_div_id_by_key(:true), :locale => 'en'})
    # 3. 日本語
    result ||= find(:first, :conditions => {:mail_type_div => mail_type_div, :use_div => MailTemplate.use_div_id_by_key(:true), :locale => 'ja'})
    # 4. 無し
    result ||= MailTemplate.new()
    return result
  end

  #
  # =メール件名を取得する=
  # options:
  #   :user Userモデルのインスタンス
  #   :first_name 名（文字列）（:userよりも優先される）
  #   :last_name　性（文字列）（:userよりも優先される）
  #   :email_address メールアドレス（文字列）（:userよりも優先される）
  #   :order Orderモデルのインスタンス
  #   :inquiry_content 問い合わせ内容（文字列）
  #
  def get_mail_subject(pc_mobile_div, options={})
    if pc_mobile_div == UserEmail.mail_address_pc_mobile_div_id_by_key(:mobile) && self.for_mobile?
      subject = ERB.new(self.mobile_subject_template) if self.mobile_subject_template
    else
      subject = ERB.new(self.pc_subject_template) if self.pc_subject_template
    end
    return ' ' if subject.blank?
    subject.result(create_bind_data(:text, options))
  end

  #
  # =メール内容を取得する=
  # options:
  #   :user Userモデルのインスタンス
  #   :first_name 名（文字列）（:userよりも優先される）
  #   :last_name　性（文字列）（:userよりも優先される）
  #   :email_address メールアドレス（文字列）（:userよりも優先される）
  #   :order Orderモデルのインスタンス
  #   :inquiry_content 問い合わせ内容（文字列）
  #
  def get_mail_body(pc_mobile_div, options={})
    if pc_mobile_div == UserEmail.mail_address_pc_mobile_div_id_by_key(:mobile) && self.for_mobile?
      body = ERB.new(self.mobile_html) if self.content_type_div_key == :text_html && self.mobile_html
      body ||= ERB.new(self.mobile_text) if self.mobile_text
    else
      body = ERB.new(self.pc_html) if self.content_type_div_key == :text_html && self.pc_html
      body ||= ERB.new(self.pc_text) if self.pc_text
    end
    return ' ' if body.blank?
    body.result(create_bind_data(self.content_type_div_key, options))
  end

  #
  # =一覧のための検索条件を生成します=
  #
  def self.create_condition(condition)
    return nil if condition.nil?
    where = Condition.block do |c|
      c.and "name", "like", "%#{condition.name}%" unless condition.name.blank?
      c.and "mail_type_div", "#{condition.mail_type_div}" unless condition.mail_type_div.blank?
      c.and "locale", "#{condition.locale}" unless condition.locale.blank?
    end
  end

  private
  # ERB構文チェック
  def validates_erb(erb, name)
    begin
      # PCHTML本文のERB構文チェック
      erb.result(template_test_obj)
    rescue SyntaxError, NoMethodError
      errors.add(name, :EM990037)
    rescue ArgumentError
      errors.add(name, :EM990038)
    rescue
      errors.add(name, :EM990039)
    end
  end

  # プレビューデータ生成
  def template_test_obj(type = :text)
    order = Order.new(:ec_order_code => '0000000000', :ordered_at => Time.now(), :locale => 'jp')
    order.order_shippings << OrderShipping.new(:order_code => '00000000000', :status_div_key => :undelivery,
      :name_last => '買物', :name_first => '太郎', :kana_name_last => 'カイモノ', :kana_name_first => 'タロウ',
      :tel_num => '000-000-0000', :zip_code => '0000000', :address_1 => '東京都', :address_2 => '足立区XXXXX１－１',
      :address_3 => 'EC-RIDERビル1F 101号', :email => 'kaimono@ec-rider.jp', :payment_type_div => '1', :total_amount => 1000,
      :shipping_cost => 600, :country_code => 'JP', :subtotal_amount => 1000)
    order.order_shippings.first.order_items << OrderItem.new(:product_name => 'Tシャツ（赤）',
      :order_product_name_1 => 'Tシャツ（赤）', :order_product_name_2 => 'T-shirt',
      :course_div => '1', :unit_price => 500, :shipping_cost => 0, :total_amount => 500, :qty => 1)
    order.order_shippings.first.order_items << OrderItem.new(:product_name => 'Tシャツ（白）',
      :order_product_name_1 => 'Tシャツ（白）', :order_product_name_2 => 'T-shirt',
      :course_div => '1', :unit_price => 500, :shipping_cost => 0, :total_amount => 500, :qty => 1)
    order.order_shippings.first.order_items.first.product_sku = ProductSku.new(:sku_code => '000000000000000000000001')
    order.order_shippings.first.order_items[1].product_sku = ProductSku.new(:sku_code => '000000000000000000000002')
    last_name = "買物"
    first_name = "太郎"
    user_name = "買物太郎"
    mail_address = 'preview@ec-rider.jp'
    order_detail = order.print_order_detail(type, {})
    order_code = 'ja00000000001'
    payment_code = '00000000001'
    inquiry_content = "質問です。\nXXXXXはできますか？\nそれとも*****でしょうか？"
    answer_content = "回答します。\nXXXXXができます。"
    shipment_code = '0000000001'
    delivery_code = '0000-0000-0000-0000'
    shipment_content = <<-END_OF_CONTENT
--- 商品リスト ---
[0000000001] 商品A JANコード(0123456789000)
 x 3個

--- 配送ラベル情報 ---
[依頼主] XXXXXXXXX
 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
[送付先] XXXXXXXXXXXXXXX
 XXXXXXXXXXXXXXXXXX

備考 XXXXXXXXXXXX
END_OF_CONTENT

    project_code = 'pj001'
    project_name = '1周年プロジェクト'
    project_period = '2010/05/01 10:00:00 ～ 2010/05/31 23:59:59'
    approval_comment = '10日までにお願いします。'
    payment_error_reason = "在庫切れ"
    payment_error_datetime = "2008/01/01 00:00:00"
    payment_code = "00000000001"
    tracking_id = "00000000001"
    payment_content = <<-EOS
pay_method:[APIで設定した値]
merchant_id:[APIで設定した値]
service_id:[APIで設定した値]
...
EOS
    payment_checked_content = <<-EOS
pay_method:[APIで通知された値]
merchant_id:[APIで通知された値]
service_id:[APIで通知された値]
...
EOS
    binding
  end

  #
  # =テンプレートにバインドするデータを生成する=
  # options:
  #   :user Userモデルのインスタンス
  #   :first_name 名（文字列）（:userよりも優先される）
  #   :last_name　性（文字列）（:userよりも優先される）
  #   :username フルネーム（文字列）（:user, :first_name, :last_nameよりも優先される）
  #   :email_address メールアドレス（文字列）（:userよりも優先される）
  #   :order EcOrderChapterモデルのインスタンス
  #   :inquiry_content 問い合わせ内容（文字列）
  #   :answer_content 問い合わせ回答内容（文字列）
  #   :order_shipping OrderChapterモデルのインスタンス
  #   :shipment_content 出荷指示詳細（文字列）
  #   :project_code プロジェクトコード（文字列）
  #   :project_name プロジェクト名（文字列）
  #   :project_period プロジェクト公開期間（文字列）
  #   :approval_comment コメント（文字列）
  #
  def create_bind_data(content_type, options = {})
    # ユーザ情報
    user = options[:user] ? options[:user] : User.new()
    mail_address = user.user_email ? user.user_email.email : ''
    last_name = user.name_last
    first_name = user.name_first
    user_name = user.user_address.fullname if user.user_address

    # ユーザ情報（項目ごとに指定されている場合）
    mail_address = options[:email_address] if options[:email_address]
    last_name = options[:last_name] if options[:last_name]
    first_name = options[:first_name] if options[:first_name]
    user_name = options[:user_name] if options[:user_name]
    user_name ||= "#{last_name} #{first_name}"

    # 注文
    order = options[:order] ? options[:order] : Order.new()
    order_detail = order.print_order_detail(content_type, options)
    order_code = order.ec_order_code

    # 出荷指示
    shipment_code = options[:order_shipping] ? options[:order_shipping].order_code : ''
    shipment_content = options[:shipment_content] ? options[:shipment_content] : ''

    # 出荷完了
    delivery_code = options[:order_shipping] ? options[:order_shipping].delivery_code : ''

    # 問い合わせ
    inquiry_content = options[:inquiry_content] ? options[:inquiry_content] : ''
    answer_content = options[:answer_content] ? options[:answer_content] : ''

    # 承認関係
    project_code = options[:project_code] ? options[:project_code] : ''
    project_name = options[:project_name] ? options[:project_name] : ''
    project_period = options[:project_period] ? options[:project_period] : ''
    approval_comment = options[:approval_comment] ? options[:approval_comment] : ''
    
    # 決済キャンセル依頼
    sps_parameter_history = !options[:sps_parameter_history].nil? ? options[:sps_parameter_history] : SpsParameterHistory.new()
    sps_result_history = !options[:sps_result_history].nil? ? options[:sps_result_history] : SpsResultHistory.new()
    payment_error_reason    = options[:payment_error_reason] ? options[:payment_error_reason] : ''
    payment_error_datetime = options[:payment_error_datetime] ? options[:payment_error_datetime] : ''
    payment_code             = sps_parameter_history.sps_order_id ? sps_parameter_history.sps_order_id : ''
    tracking_id              = sps_result_history.res_tracking_id ? sps_result_history.res_tracking_id : ''
    payment_content          = sps_parameter_history.create_payment_content
    payment_checked_content  = sps_result_history.create_payment_checked_content
    
    binding
  end

  class SearchCondition < ActiveForm
    include ActiveRecord::Validations
    attr_accessor :name, :mail_type_div, :locale, :disp_count
  end

end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/models/mail_template.rb <==
# -*- coding: utf-8 -*-
require 'erb'
class MailTemplate < ActiveRecord::Base
  include EcRider::PluginModule::Extendable
  acts_as_paranoid
  attr_accessor :validate_for_pc_only
  attr_accessor :disp_count

  selectable_attr :mail_type_div do
    entry '1', :thanks, '注文受付メール', :pc_only => false
    entry '15', :thanks_bank_transfer, '注文受付（銀行振り込み）メール', :pc_only => false
    entry '2', :regist_user, 'ユーザ登録メール', :pc_only => false
    entry '19', :regist_user_error, 'ユーザ登録エラーメール', :pc_only => false
    entry '3', :update_user, 'ユーザ退会メール', :pc_only => false
    entry '4', :cancel, 'キャンセル依頼メール', :pc_only => false
    entry '5', :cancel_complete, 'キャンセル完了メール', :pc_only => false
    entry '6', :inquiry, '問い合わせ受付メール', :pc_only => false
    entry '7', :reply, '問い合わせ回答メール', :pc_only => false
    entry '8', :order_reply, '注文問い合わせ回答メール', :pc_only => false
    entry '9', :shipment_instruction, '出荷指示メール', :pc_only => false, :ja_only => true
    entry '17', :shipment_complete_for_shop, '出荷完了メール（店舗宛て）', :pc_only => true, :ja_only => true
    entry '10', :shipment_complete, '出荷完了メール（顧客宛て）', :pc_only => false
    entry '14', :cancel_payment, '決済取り消し依頼メール', :pc_only => true, :ja_only => true # プラグインgp0004にて実装されているため、本体にはありません。
    entry '16', :receipt_payment, '入金確認メール', :pc_only => false
    entry '11', :project_check_request, 'プロジェクト確認依頼メール', :pc_only => true
    entry '12', :project_approval_request, 'プロジェクト承認依頼メール', :pc_only => true
    entry '13', :project_passback, 'プロジェクト差し戻しメール', :pc_only => true
    entry '18', :returned, '返品完了メール', :pc_only => false
    entry '98', :payment_error, '決済エラー連絡メール', :pc_only => true
    entry '99', :free, 'その他のメール', :pc_only => false
    update_with_plugins(:MailTemplate, :added_entries_for_mail_type_div)
  end
  def self.added_entries_for_mail_type_div(mod); end

  selectable_attr :content_type_div do
    entry '1', :text, 'テキストのみ'
    entry '2', :text_html, 'テキストとHTML形式'
  end

  selectable_attr :use_div do
    entry '0', :false, ' '
    entry '1', :true, '使用中'
  end

  # 必須チェック
  validates_presence_of :name, :mail_type_div, :pc_subject_template, :pc_text
  validates_presence_of :pc_html, :if => Proc.new{|t|t.content_type_div == MailTemplate.content_type_div_id_by_key(:text_html)}
  validates_presence_of :mobile_subject_template, :if => :for_mobile?
  validates_presence_of :mobile_text, :if => :for_mobile?
  validates_presence_of :mobile_html, :if => Proc.new{|t|t.content_type_div == MailTemplate.content_type_div_id_by_key(:text_html) && t.for_mobile?}

  # ユニークチェック
  validates_uniqueness_of :name

  # 長さチェック
  validates_length_of :name, :maximum => 255
  validates_length_of :pc_subject_template, :maximum => 255
  validates_length_of :pc_text, :maximum => 20000
  validates_length_of :mobile_subject_template, :maximum => 255, :if => :for_mobile?
  validates_format_of :content_type_div, :with => /^[1|2]$/

  # モバイルのチェックもする場合はtrueを返す
  def for_mobile?
    return !(self.validate_for_pc_only || self.mail_type_div_entry[:pc_only])
  end

  def validate
    if self.errors.size < 1
      validates_erb(ERB.new(self.pc_subject_template), 'pc_subject')
      validates_erb(ERB.new(self.pc_text), 'pc_text')
      validates_erb(ERB.new(self.pc_html), 'pc_html') if self.content_type_div_key == :text_html
      if for_mobile?
        validates_erb(ERB.new(self.mobile_subject_template), 'mobile_subject')
        validates_erb(ERB.new(self.mobile_text), 'mobile_text')
        validates_erb(ERB.new(self.mobile_html), 'mobile_html') if self.content_type_div_key == :text_html
      end
    end
  end

  # テンプレートの変更を反映して、使用区分を変更する
  def save_and_change_use_div
    MailTemplate.transaction do
      self.save!
      if self.use_div_key == :true
        mail_templates = MailTemplate.find(:all, :conditions => ['id != ? AND mail_type_div = ? AND use_div = ? AND locale = ?', self.id, self.mail_type_div, self.use_div, self.locale])
        mail_templates.each do |template|
          template.use_div = MailTemplate.use_div_id_by_key(:false)
          template.save!
        end
      end
    end
  end

  # メール件名をプレビューする
  def preview_mail_subject(pc_mobile_key)
    if pc_mobile_key == :mobile
      subject = ERB.new(self.mobile_subject_template) if self.mobile_subject_template
    else
      subject = ERB.new(self.pc_subject_template) if self.pc_subject_template
    end
    return ' ' if subject.blank?
    subject.result(template_test_obj(:text))
  end

  # メール本文をプレビューする
  def preview_mail_body(pc_mobile_key, text_html_key)
    if pc_mobile_key == :mobile && text_html_key == :html
      body = ERB.new(self.mobile_html)
    elsif pc_mobile_key == :mobile && text_html_key == :text
      body = ERB.new(self.mobile_text)
    elsif pc_mobile_key == :pc && text_html_key == :html
      body = ERB.new(self.pc_html)
    else
      body = ERB.new(self.pc_text)
    end

    return ' ' if body.blank?
    body.result(template_test_obj(text_html_key))
  end

  # 引数に渡されたメール区分の使用中テンプレートを取得する
  def self.find_valid_template(mail_type_key, locale = I18n.locale.to_s)
    mail_type_div = MailTemplate.mail_type_div_id_by_key(mail_type_key)

    #下記の順番でテンプレートを検索する
    # 1. 指定した言語
    result = find(:first, :conditions => {:mail_type_div => mail_type_div, :use_div => MailTemplate.use_div_id_by_key(:true), :locale => locale})
    # 2. 英語
    result ||= find(:first, :conditions => {:mail_type_div => mail_type_div, :use_div => MailTemplate.use_div_id_by_key(:true), :locale => 'en'})
    # 3. 日本語
    result ||= find(:first, :conditions => {:mail_type_div => mail_type_div, :use_div => MailTemplate.use_div_id_by_key(:true), :locale => 'ja'})
    # 4. 無し
    result ||= MailTemplate.new()
    return result
  end

  #
  # =メール件名を取得する=
  # options:
  #   :user Userモデルのインスタンス
  #   :first_name 名（文字列）（:userよりも優先される）
  #   :last_name　性（文字列）（:userよりも優先される）
  #   :email_address メールアドレス（文字列）（:userよりも優先される）
  #   :order Orderモデルのインスタンス
  #   :inquiry_content 問い合わせ内容（文字列）
  #
  def get_mail_subject(pc_mobile_div, options={})
    if pc_mobile_div == UserEmail.mail_address_pc_mobile_div_id_by_key(:mobile) && self.for_mobile?
      subject = ERB.new(self.mobile_subject_template) if self.mobile_subject_template
    else
      subject = ERB.new(self.pc_subject_template) if self.pc_subject_template
    end
    return ' ' if subject.blank?
    subject.result(create_bind_data(:text, options))
  end

  #
  # =メール内容を取得する=
  # options:
  #   :user Userモデルのインスタンス
  #   :first_name 名（文字列）（:userよりも優先される）
  #   :last_name　性（文字列）（:userよりも優先される）
  #   :email_address メールアドレス（文字列）（:userよりも優先される）
  #   :order Orderモデルのインスタンス
  #   :inquiry_content 問い合わせ内容（文字列）
  #
  def get_mail_body(pc_mobile_div, options={})
    if pc_mobile_div == UserEmail.mail_address_pc_mobile_div_id_by_key(:mobile) && self.for_mobile?
      body = ERB.new(self.mobile_html) if self.content_type_div_key == :text_html && self.mobile_html
      body ||= ERB.new(self.mobile_text) if self.mobile_text
    else
      body = ERB.new(self.pc_html) if self.content_type_div_key == :text_html && self.pc_html
      body ||= ERB.new(self.pc_text) if self.pc_text
    end
    return ' ' if body.blank?
    body.result(create_bind_data(self.content_type_div_key, options))
  end

  #
  # =一覧のための検索条件を生成します=
  #
  def self.create_condition(condition)
    return nil if condition.nil?
    where = Condition.block do |c|
      c.and "name", "like", "%#{condition.name}%" unless condition.name.blank?
      c.and "mail_type_div", "#{condition.mail_type_div}" unless condition.mail_type_div.blank?
      c.and "locale", "#{condition.locale}" unless condition.locale.blank?
    end
  end

  private
  # ERB構文チェック
  def validates_erb(erb, name)
    begin
      # PCHTML本文のERB構文チェック
      erb.result(template_test_obj)
    rescue SyntaxError, NoMethodError
      errors.add(name, :EM990037)
    rescue ArgumentError
      errors.add(name, :EM990038)
    rescue
      errors.add(name, :EM990039)
    end
  end

  # プレビューデータ生成
  def template_test_obj(type = :text)
    order = Order.new(:ec_order_code => '0000000000', :ordered_at => Time.now(), :locale => 'jp')
    order.order_shippings << OrderShipping.new(:order_code => '00000000000', :status_div_key => :undelivery,
      :name_last => '買物', :name_first => '太郎', :kana_name_last => 'カイモノ', :kana_name_first => 'タロウ',
      :tel_num => '000-000-0000', :zip_code => '0000000', :address_1 => '東京都', :address_2 => '足立区XXXXX１－１',
      :address_3 => 'EC-RIDERビル1F 101号', :email => 'kaimono@ec-rider.jp', :payment_type_div => '1', :total_amount => 1000,
      :shipping_cost => 600, :country_code => 'JP', :subtotal_amount => 1000)
    order.order_shippings.first.order_items << OrderItem.new(:product_name => 'Tシャツ（赤）',
      :order_product_name_1 => 'Tシャツ（赤）', :order_product_name_2 => 'T-shirt',
      :course_div => '1', :unit_price => 500, :shipping_cost => 0, :total_amount => 500, :qty => 1)
    order.order_shippings.first.order_items << OrderItem.new(:product_name => 'Tシャツ（白）',
      :order_product_name_1 => 'Tシャツ（白）', :order_product_name_2 => 'T-shirt',
      :course_div => '1', :unit_price => 500, :shipping_cost => 0, :total_amount => 500, :qty => 1)
    order.order_shippings.first.order_items.first.product_sku = ProductSku.new(:sku_code => '000000000000000000000001')
    order.order_shippings.first.order_items[1].product_sku = ProductSku.new(:sku_code => '000000000000000000000002')
    last_name = "買物"
    first_name = "太郎"
    user_name = "買物太郎"
    mail_address = 'preview@ec-rider.jp'
    order_detail = order.print_order_detail(type, {})
    order_code = 'ja00000000001'
    payment_code = '00000000001'
    inquiry_content = "質問です。\nXXXXXはできますか？\nそれとも*****でしょうか？"
    answer_content = "回答します。\nXXXXXができます。"
    shipment_code = '0000000001'
    delivery_code = '0000-0000-0000-0000'
    delivery_status_url = 'http://ec-one.unsou.co.jp/turl'
    shipment_content = <<-END_OF_CONTENT
--- 商品リスト ---
[0000000001] 商品A JANコード(0123456789000)
 x 3個

--- 配送ラベル情報 ---
[依頼主] XXXXXXXXX
 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
[送付先] XXXXXXXXXXXXXXX
 XXXXXXXXXXXXXXXXXX

備考 XXXXXXXXXXXX
END_OF_CONTENT

    project_code = 'pj001'
    project_name = '1周年プロジェクト'
    project_period = '2010/05/01 10:00:00 ～ 2010/05/31 23:59:59'
    approval_comment = '10日までにお願いします。'
    payment_error_reason = "在庫切れ"
    payment_error_datetime = "2008/01/01 00:00:00"
    payment_code = "00000000001"
    tracking_id = "00000000001"
    payment_content = <<-EOS
pay_method:[APIで設定した値]
merchant_id:[APIで設定した値]
service_id:[APIで設定した値]
...
EOS
    payment_checked_content = <<-EOS
pay_method:[APIで通知された値]
merchant_id:[APIで通知された値]
service_id:[APIで通知された値]
...
EOS
    binding
  end

  #
  # =テンプレートにバインドするデータを生成する=
  # options:
  #   :user Userモデルのインスタンス
  #   :first_name 名（文字列）（:userよりも優先される）
  #   :last_name　性（文字列）（:userよりも優先される）
  #   :username フルネーム（文字列）（:user, :first_name, :last_nameよりも優先される）
  #   :email_address メールアドレス（文字列）（:userよりも優先される）
  #   :order EcOrderChapterモデルのインスタンス
  #   :inquiry_content 問い合わせ内容（文字列）
  #   :answer_content 問い合わせ回答内容（文字列）
  #   :order_shipping OrderChapterモデルのインスタンス
  #   :shipment_content 出荷指示詳細（文字列）
  #   :project_code プロジェクトコード（文字列）
  #   :project_name プロジェクト名（文字列）
  #   :project_period プロジェクト公開期間（文字列）
  #   :approval_comment コメント（文字列）
  #
  def create_bind_data(content_type, options = {})
    # ユーザ情報
    user = options[:user] ? options[:user] : User.new()
    mail_address = user.user_email ? user.user_email.email : ''
    last_name = user.name_last
    first_name = user.name_first
    user_name = user.user_address.fullname if user.user_address

    # ユーザ情報（項目ごとに指定されている場合）
    mail_address = options[:email_address] if options[:email_address]
    last_name = options[:last_name] if options[:last_name]
    first_name = options[:first_name] if options[:first_name]
    user_name = options[:user_name] if options[:user_name]
    user_name ||= "#{last_name} #{first_name}"

    # 注文
    order = options[:order] ? options[:order] : Order.new()
    order_detail = order.print_order_detail(content_type, options)
    order_code = order.ec_order_code

    # 出荷指示
    shipment_code = options[:order_shipping] ? options[:order_shipping].order_code : ''
    shipment_content = options[:shipment_content] ? options[:shipment_content] : ''

    # 出荷完了
    delivery_code = options[:order_shipping] ? options[:order_shipping].delivery_code : ''
    distributor = options[:order_shipping].country.distributor if options[:order_shipping] && options[:order_shipping].country
    delivery_status_url = distributor ? distributor.url : ''

    # 問い合わせ
    inquiry_content = options[:inquiry_content] ? options[:inquiry_content] : ''
    answer_content = options[:answer_content] ? options[:answer_content] : ''

    # 承認関係
    project_code = options[:project_code] ? options[:project_code] : ''
    project_name = options[:project_name] ? options[:project_name] : ''
    project_period = options[:project_period] ? options[:project_period] : ''
    approval_comment = options[:approval_comment] ? options[:approval_comment] : ''
    
    # 決済キャンセル依頼
    # TODO SPS決済プラグインへ移動
    payment_error_reason    = options[:payment_error_reason] ? options[:payment_error_reason] : ''
    payment_error_datetime = options[:payment_error_datetime] ? options[:payment_error_datetime] : ''
    payment_code             = get_payment_code(options)
    tracking_id              = get_tracking_id(options)
    payment_content          = get_payment_content(options)
    payment_checked_content  = payment_checked_content(options)
    
    binding
  end

  private
  # バインドデータプラグイン拡張用メソッド
  def get_payment_code(options)
    return ''
  end

  def get_tracking_id(options)
    return ''
  end

  def get_payment_content(options)
    return ''
  end

  def payment_checked_content(options)
    return ''
  end
  public
  class SearchCondition < ActiveForm
    include ActiveRecord::Validations
    attr_accessor :name, :mail_type_div, :locale, :disp_count
  end

end
